==> home-library-jcr-1.0.0-20120905.022836-21-sources.jar: org/gcube/portlets/user/homelibrary/jcr/workspace/folder/items/JCRExternalUrl.java <==
package org.gcube.portlets.user.homelibrary.jcr.workspace.folder.items;

import java.io.ByteArrayInputStream;
import java.io.IOException;
import javax.jcr.Node;
import javax.jcr.RepositoryException;
import org.apache.commons.lang.Validate;
import org.gcube.portlets.user.homelibrary.home.exceptions.InternalErrorException;
import org.gcube.portlets.user.homelibrary.home.workspace.folder.FolderItemType;
import org.gcube.portlets.user.homelibrary.home.workspace.folder.items.ExternalUrl;
import org.gcube.portlets.user.homelibrary.jcr.workspace.JCRWorkspace;
import org.gcube.portlets.user.homelibrary.util.Util;

public class JCRExternalUrl extends JCRWorkspaceFolderItem implements
		ExternalUrl {
	
	private static final String NT_FILE = "nt:resource";
	
	protected final JCRFile content;
	
	public JCRExternalUrl(JCRWorkspace workspace, Node node) throws RepositoryException, InternalErrorException {
		super(workspace,node);
		this.content = new JCRFile(node.getNode(CONTENT));
	}

	public JCRExternalUrl(JCRWorkspace workspace, Node node, String name, String description,
			String url) throws RepositoryException  {
		super(workspace, node, name, description);
		
		Validate.notNull(url, "url must be not null");

		this.content = new JCRFile(node.addNode(CONTENT,NT_FILE),
				new ByteArrayInputStream(url.getBytes()));
		node.setProperty(FOLDER_ITEM_TYPE, FolderItemType.EXTERNAL_URL.toString());	
	}

	@Override
	public long getLength() throws InternalErrorException {
		try {
			return Util.readStreamAsString((content.getData())).length();
		} catch (IOException e) {
			throw new InternalErrorException(e);
		}
	}

	@Override
	public String getUrl() throws InternalErrorException {
		try {
			return Util.readStreamAsString((content.getData()));
		} catch (IOException e) {
			throw new InternalErrorException(e);
		}
	}

	@Override
	public FolderItemType getFolderItemType() {
		return FolderItemType.EXTERNAL_URL;
	}

	@Override
	public void saveContent(Node node) throws RepositoryException {
		content.save(node);
	}

}

==> home-library-jcr-1.1.0-20121120.221249-44-sources.jar: org/gcube/portlets/user/homelibrary/jcr/workspace/folder/items/JCRExternalUrl.java <==
package org.gcube.portlets.user.homelibrary.jcr.workspace.folder.items;

import java.io.ByteArrayInputStream;
import java.io.IOException;
import javax.jcr.Node;
import javax.jcr.RepositoryException;
import org.apache.commons.lang.Validate;
import org.gcube.portlets.user.homelibrary.home.exceptions.InternalErrorException;
import org.gcube.portlets.user.homelibrary.home.workspace.folder.FolderItemType;
import org.gcube.portlets.user.homelibrary.home.workspace.folder.items.ExternalUrl;
import org.gcube.portlets.user.homelibrary.jcr.workspace.JCRWorkspace;
import org.gcube.portlets.user.homelibrary.util.Util;

public class JCRExternalUrl extends JCRWorkspaceFolderItem implements
		ExternalUrl {
	

	
	protected final JCRFile content;
	
	public JCRExternalUrl(JCRWorkspace workspace, Node node) throws RepositoryException, InternalErrorException {
		super(workspace,node);
		this.content = new JCRFile(node.getNode(CONTENT));
	}

	public JCRExternalUrl(JCRWorkspace workspace, Node node, String name, String description,
			String url) throws RepositoryException  {
		super(workspace, node, name, description);
		
		Validate.notNull(url, "url must be not null");

		this.content = new JCRFile(node.addNode(CONTENT,ContentType.GENERAL.toString()),
				new ByteArrayInputStream(url.getBytes()));
		node.setProperty(FOLDER_ITEM_TYPE, FolderItemType.EXTERNAL_URL.toString());	
	}

	@Override
	public long getLength() throws InternalErrorException {
		try {
			return Util.readStreamAsString((content.getData())).length();
		} catch (IOException e) {
			throw new InternalErrorException(e);
		}
	}

	@Override
	public String getUrl() throws InternalErrorException {
		try {
			return Util.readStreamAsString((content.getData()));
		} catch (IOException e) {
			throw new InternalErrorException(e);
		}
	}

	@Override
	public FolderItemType getFolderItemType() {
		return FolderItemType.EXTERNAL_URL;
	}

	@Override
	public void saveContent(Node node) throws RepositoryException {
		content.save(node);
	}

}
